# EIS_Fitting_Yang
THis is a package for EIS fitting and plotting.
Transmission line models are included in several equivalent circuits.
The fitting curves of individual components in the circuit will be plotted under the overall fitting curve.

The codes were written when work-from-home during the COVID-19 pandemic. Sincerely hope no more people dies from it.

My newborn girl Erica surely "inspired" me a lot with her often loud and clear crying. This is also a gift to dear Erica.


